Class: Fixnum

Inherits:
Object
  • Object
show all
Includes:
HigherExpectations::InstanceMethods
Defined in:
lib/higher_expectations.rb

Overview

Provides instance methods for Fixnum class, which due to limitiations mentioned above must be treated as a special case

Method Summary

Methods included from HigherExpectations::InstanceMethods

#must_be, #must_be_a, #must_be_in_range, #must_be_nil, #must_match, #must_not_be, #must_not_be_a, #must_not_be_in_range, #must_not_be_nil, #must_not_match, #must_not_respond_to, #must_respond_to, #raise_ae